@@ -19,7 +19,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #ifndef NAUTILUS_FILE_H
@@ -52,7 +52,7 @@ typedef struct NautilusFile NautilusFile;
 
 typedef enum {
 	NAUTILUS_FILE_SORT_NONE,
-	NAUTILUS_FILE_SORT_BY_NAME,
+	NAUTILUS_FILE_SORT_BY_DISPLAY_NAME,
 	NAUTILUS_FILE_SORT_BY_DIRECTORY,
 	NAUTILUS_FILE_SORT_BY_SIZE,
 	NAUTILUS_FILE_SORT_BY_TYPE,
@@ -122,6 +122,7 @@ void                    nautilus_file_invalidate_all_attributes         (Nautilu
 
 /* Basic attributes for file objects. */
 gboolean                nautilus_file_contains_text                     (NautilusFile                   *file);
+char *                  nautilus_file_get_display_name                  (NautilusFile                   *file);
 char *                  nautilus_file_get_name                          (NautilusFile                   *file);
 char *                  nautilus_file_get_uri                           (NautilusFile                   *file);
 char *                  nautilus_file_get_uri_scheme                    (NautilusFile                   *file);
@@ -270,7 +271,7 @@ int                     nautilus_file_compare_for_sort                  (Nautilu
 									 NautilusFileSortType            sort_type,
 									 gboolean			 directories_first,
 									 gboolean		  	 reversed);
-int                     nautilus_file_compare_name                      (NautilusFile                   *file_1,
+int                     nautilus_file_compare_display_name              (NautilusFile                   *file_1,
 									 const char                     *pattern);
 
 /* filtering functions for use by various directory views */
@@ -290,6 +291,9 @@ GList                  *nautilus_file_list_filter_hidden_and_backup     (GList
  */
 char *                  nautilus_file_get_activation_uri                (NautilusFile                   *file);
 
+/* Get custom icon (if specified by metadata or link contents) */
+char *                  nautilus_file_get_custom_icon_uri               (NautilusFile                   *file);
+
 /* Convenience functions for dealing with a list of NautilusFile objects that each have a ref.
  * These are just convenient names for functions that work on lists of GtkObject *.
  */
@@ -297,7 +301,7 @@ GList *                 nautilus_file_list_ref                          (GList
 void                    nautilus_file_list_unref                        (GList                          *file_list);
 void                    nautilus_file_list_free                         (GList                          *file_list);
 GList *                 nautilus_file_list_copy                         (GList                          *file_list);
-GList *			nautilus_file_list_sort_by_name			(GList				*file_list);
+GList *			nautilus_file_list_sort_by_display_name		(GList				*file_list);
 
 /* Debugging */
 void                    nautilus_file_dump                              (NautilusFile                   *file);
