@@ -36,12 +36,13 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <gtk/gtkmain.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus/nautilus-bonobo-workarounds.h>
 #include <stdlib.h>
 
@@ -239,7 +240,10 @@ destroy (GtkObject *object)
 	if (metafile->details->private_vfs_uri != NULL) {
 		gnome_vfs_uri_unref (metafile->details->private_vfs_uri);
 	}
-	
+	if (metafile->details->directory_vfs_uri != NULL) {
+		gnome_vfs_uri_unref (metafile->details->directory_vfs_uri);
+	}
+
 	g_hash_table_remove (metafiles, metafile->details->directory_uri);
 	
 	metafile_free_metadata (metafile);
@@ -247,6 +251,8 @@ destroy (GtkObject *object)
 
 	g_assert (metafile->details->write_idle_id == 0);
 
+	g_free (metafile->details->directory_uri);
+
 	g_free (metafile->details);
 
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
@@ -650,7 +656,7 @@ find_monitor_node (GList *monitors, const Nautilus_MetafileMonitor monitor)
 		}
 	}
 	
-	/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+	/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 
 	CORBA_exception_free (&ev);
 	
@@ -705,7 +711,7 @@ nautilus_metafile_notify_metafile_ready (NautilusMetafile *metafile)
 	for (node = metafile->details->monitors; node != NULL; node = node->next) {
 		monitor = node->data;
 		Nautilus_MetafileMonitor_metafile_ready (monitor, &ev);
-		/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+		/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	}
 	
 	CORBA_exception_free (&ev);
@@ -724,7 +730,7 @@ call_metafile_changed (NautilusMetafile *metafile,
 	for (node = metafile->details->monitors; node != NULL; node = node->next) {
 		monitor = node->data;
 		Nautilus_MetafileMonitor_metafile_changed (monitor, file_names, &ev);
-		/* FIXME bugzilla.eazel.com 6664: examine ev for errors */
+		/* FIXME bugzilla.gnome.org 46664: examine ev for errors */
 	}
 	
 	CORBA_exception_free (&ev);
@@ -1524,7 +1530,7 @@ copy_file_metadata (NautilusMetafile *source_metafile,
 	g_return_if_fail (NAUTILUS_IS_METAFILE (destination_metafile));
 	g_return_if_fail (destination_file_name != NULL);
 
-	/* FIXME bugzilla.eazel.com 3343: This does not properly
+	/* FIXME bugzilla.gnome.org 43343: This does not properly
 	 * handle the case where we don't have the source metadata yet
 	 * since it's not read in.
 	 */
@@ -1543,7 +1549,7 @@ copy_file_metadata (NautilusMetafile *source_metafile,
 			g_hash_table_insert (destination_metafile->details->node_hash,
 					     xmlMemStrdup (destination_file_name), node);
 		} else {
-			/* FIXME bugzilla.eazel.com 6526: Copying data into a destination
+			/* FIXME bugzilla.gnome.org 46526: Copying data into a destination
 			 * where the metafile was not yet read is not implemented.
 			 */
 			g_warning ("not copying metadata");
@@ -1890,7 +1896,7 @@ allow_metafile (NautilusMetafile *metafile)
 	 * hardcode the schemes that are good for metadata instead of
 	 * the schemes that are bad for it.
 	 */
-	/* FIXME bugzilla.eazel.com 2434: 
+	/* FIXME bugzilla.gnome.org 42434: 
 	 * We need to handle this in a better way. Perhaps a
 	 * better way can wait until we have support for metadata
 	 * access inside gnome-vfs.
