@@ -26,6 +26,7 @@
 #include "nautilus-thumbnails.h"
 
 #include "nautilus-directory-notify.h"
+#include "nautilus-global-preferences.h"
 #include "nautilus-icon-factory-private.h"
 #include "nautilus-theme.h"
 #include "nautilus-thumbnails-jpeg.h"
@@ -34,7 +35,7 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtkmain.h>
-#include <libgnomevfs/gnome-vfs-file-info.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <librsvg/rsvg.h>
 #include <stdio.h>
 #include <string.h>
@@ -73,7 +74,7 @@ vfs_file_exists (const char *file_uri)
 		return FALSE;
 	}	
 
-	/* FIXME bugzilla.eazel.com 3137: The synchronous I/O here
+	/* FIXME bugzilla.gnome.org 43137: The synchronous I/O here
 	 * means this call is unsuitable for use on anything that
 	 * might be remote.
 	 */
@@ -83,37 +84,104 @@ vfs_file_exists (const char *file_uri)
 	return result;
 }
 
+static gboolean
+uri_is_local (const char *uri)
+{
+	gboolean is_local;
+	GnomeVFSURI *vfs_uri;
+
+	vfs_uri = gnome_vfs_uri_new (uri);
+	is_local = gnome_vfs_uri_is_local (vfs_uri);
+	gnome_vfs_uri_unref (vfs_uri);
+
+	return is_local;
+}
+
+static gboolean
+prefer_global_thumbnails_location (const char *image_uri)
+{
+	static int public_metadata_preference;
+	static gboolean public_metadata_preference_registered;
+
+	if (!public_metadata_preference_registered) {
+		eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_USE_PUBLIC_METADATA,
+						  &public_metadata_preference);
+		public_metadata_preference_registered = TRUE;
+	}
+
+	if (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_NEVER) {
+		return TRUE;
+	}
+
+	if (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_ALWAYS) {
+		return FALSE;
+	}
+
+	g_assert (public_metadata_preference == NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY);
+	return !uri_is_local (image_uri);
+}
+
+/* this functions looks for a password in a uri and changes it for 6 'x' */
+
+static char *
+obfuscate_password (const char *escaped_uri)
+{
+	const char *passwd_start, *passwd_end;
+        char *new_uri, *new_uri_temp;
+
+	passwd_start = strchr (escaped_uri, ':');
+	g_assert (passwd_start != NULL);
+	passwd_start = strchr (passwd_start + 1, ':'); /* The fisrt ':' is for the protocol */
+	if (passwd_start == NULL) { /* There's no password */
+		return g_strdup (escaped_uri);
+	}
+	passwd_end = strchr (passwd_start, '@');
+
+	/* This URL has no valid password */
+	if (passwd_end == NULL || passwd_start == NULL || passwd_end <= passwd_start) {
+		return g_strdup (escaped_uri);
+	} else {
+		new_uri_temp = g_strndup (escaped_uri, passwd_start - escaped_uri);
+		new_uri = g_strdup_printf ("%s:xxxxxx%s", new_uri_temp, passwd_end);
+		g_free (new_uri_temp);
+		return new_uri;
+	}
+}
+
 /* utility routine that, given the uri of an image, constructs the uri to the corresponding thumbnail */
 
 static char *
 make_thumbnail_uri (const char *image_uri, gboolean directory_only, gboolean use_local_directory,
-		    gboolean anti_aliased, gboolean create_parents_if_needed)
+		    gboolean create_parents_if_needed)
 {
-	GnomeVFSURI  *vfs_uri;
 	char *thumbnail_uri, *thumbnail_path;
 	char *directory_name = g_strdup (image_uri);
 	char *last_slash = strrchr (directory_name, '/');
-	char *dot_pos, *slash_pos;
-	gboolean is_local;
 	
 	*last_slash = '\0';
-
-	vfs_uri = gnome_vfs_uri_new (image_uri);
-	is_local = gnome_vfs_uri_is_local (vfs_uri);
-	gnome_vfs_uri_unref (vfs_uri);	
 	
-	/* either use the local directory or one in the user's home directory, as selected by the passed in flag */
-	if (use_local_directory && is_local) {
+	/* Either use the local directory or one in the user's home directory, 
+	 * as selected by the passed in flag and possibly overridden by user
+	 * preference.
+	 */
+	/* FIXME: Most callers set use_local_directory to the result of 
+	 * uri_is_local (image_uri), which is then done again in
+	 * prefer_global_thumbnails_location. This should be cleaned up.
+	 */
+	if (use_local_directory && !prefer_global_thumbnails_location (image_uri)) {
 		thumbnail_uri = g_strdup_printf ("%s/.thumbnails", directory_name);
 	} else  {
 		GnomeVFSResult result;
 		GnomeVFSURI *thumbnail_directory_uri;
 	        	
-		char *escaped_uri = gnome_vfs_escape_slashes (directory_name);		
-		thumbnail_path = g_strdup_printf ("%s/.nautilus/thumbnails/%s", g_get_home_dir(), escaped_uri);
+		char *escaped_uri = gnome_vfs_escape_slashes (directory_name);
+		char *protected_uri = obfuscate_password (escaped_uri);
+		
+		g_free (escaped_uri);
+		thumbnail_path = g_strdup_printf ("%s/.nautilus/thumbnails/%s", g_get_home_dir(), protected_uri);
 		thumbnail_uri = gnome_vfs_get_uri_from_local_path (thumbnail_path);
 		g_free (thumbnail_path);
-		g_free(escaped_uri);
+		g_free (protected_uri);
 		
 		/* we must create the directory if it doesn't exist */
 			
@@ -125,7 +193,7 @@ make_thumbnail_uri (const char *image_uri, gboolean directory_only, gboolean use
 				return NULL;
 			}
 		}
-		/* FIXME bugzilla.eazel.com 3137: synchronous I/O - it
+		/* FIXME bugzilla.gnome.org 43137: synchronous I/O - it
                    looks like the URI will be local-only, but best to
                    make sure. */
 
@@ -138,21 +206,7 @@ make_thumbnail_uri (const char *image_uri, gboolean directory_only, gboolean use
 		char* old_uri = thumbnail_uri;
 		thumbnail_uri = g_strdup_printf ("%s/%s", thumbnail_uri, last_slash + 1);
 		g_free(old_uri);			
-	
-		/* append the anti-aliased suffix if necessary */
-		if (anti_aliased) {
-			char *old_uri = thumbnail_uri;
-			dot_pos = strrchr (thumbnail_uri, '.');
-			slash_pos = strrchr (thumbnail_uri, '/');
-			if (dot_pos && dot_pos > slash_pos) {
-				*dot_pos = '\0';
-				thumbnail_uri = g_strdup_printf ("%s.aa.%s", old_uri, dot_pos + 1);
-			} else {
-				thumbnail_uri = g_strconcat (old_uri, ".aa", NULL);				
-			}
-			g_free (old_uri);
-		}
-		
+			
 		/* append an image suffix if the correct one isn't already present */
 		if (!eel_istr_has_suffix (image_uri, ".png")) {		
 			char *old_uri = thumbnail_uri;
@@ -166,32 +220,25 @@ make_thumbnail_uri (const char *image_uri, gboolean directory_only, gboolean use
 }
 
 /* utility routine that takes two uris and returns true if the first file has been modified later than the second */
-/* FIXME bugzilla.eazel.com 2565: it makes synchronous file info calls, so for now, it returns FALSE if either of the uri's are non-local */
+/* FIXME bugzilla.gnome.org 42565: it makes synchronous file info calls, so for now, it returns FALSE if either of the uri's are non-local */
 static gboolean
-first_file_more_recent(const char* file_uri, const char* other_file_uri)
+first_file_more_recent (const char* file_uri, const char* other_file_uri)
 {
-	GnomeVFSURI *vfs_uri, *other_vfs_uri;
-	gboolean more_recent, is_local;
+	gboolean more_recent;
 	
 	GnomeVFSFileInfo *file_info, *other_file_info;
 
 	/* if either file is remote, return FALSE.  Eventually we'll make this async to fix this */
-	vfs_uri = gnome_vfs_uri_new(file_uri);
-	other_vfs_uri = gnome_vfs_uri_new(other_file_uri);
-	is_local = gnome_vfs_uri_is_local (vfs_uri) && gnome_vfs_uri_is_local (other_vfs_uri);
-	gnome_vfs_uri_unref(vfs_uri);
-	gnome_vfs_uri_unref(other_vfs_uri);
-	
-	if (!is_local) {
+	if (!uri_is_local (file_uri) || !uri_is_local (other_file_uri)) {
 		return FALSE;
 	}
 	
 	/* gather the info and then compare modification times */
 	file_info = gnome_vfs_file_info_new ();
-	gnome_vfs_get_file_info (file_uri, file_info, GNOME_VFS_FILE_INFO_DEFAULT);
+	gnome_vfs_get_file_info (file_uri, file_info, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 	
 	other_file_info = gnome_vfs_file_info_new ();
-	gnome_vfs_get_file_info (other_file_uri, other_file_info, GNOME_VFS_FILE_INFO_DEFAULT);
+	gnome_vfs_get_file_info (other_file_uri, other_file_info, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
 	more_recent = file_info->mtime > other_file_info->mtime;
 
@@ -206,7 +253,6 @@ first_file_more_recent(const char* file_uri, const char* other_file_uri)
 typedef struct {
 	char *thumbnail_uri;
 	gboolean is_local;
-	gboolean anti_aliased;
 	pid_t thumbnail_task;
 } NautilusThumbnailInfo;
 
@@ -242,21 +288,16 @@ make_invalid_thumbnail_uri (const char *thumbnail_uri)
  * file, which indicates that a previous thumbnailing attempt failed and
  * we should use the mime-type icon instead
  */
-gboolean nautilus_thumbnail_has_invalid_thumbnail (NautilusFile *file,
-						   gboolean anti_aliased)
+gboolean
+nautilus_thumbnail_has_invalid_thumbnail (NautilusFile *file)
 {
 	char *file_uri, *thumbnail_uri, *invalid_thumbnail_uri;
-	GnomeVFSURI *temp_uri;
-	gboolean uri_is_local, is_invalid;
+	gboolean is_invalid;
 	
 	file_uri = nautilus_file_get_uri (file);
 	
-	/* compose the uri for the thumbnail locally */
-	temp_uri = gnome_vfs_uri_new (file_uri);
-	uri_is_local = gnome_vfs_uri_is_local (temp_uri);
-	gnome_vfs_uri_unref (temp_uri);
 	
-	thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, uri_is_local, anti_aliased, TRUE);
+	thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, uri_is_local (file_uri), TRUE);
 	invalid_thumbnail_uri = make_invalid_thumbnail_uri (thumbnail_uri);
 	
 	is_invalid = vfs_file_exists (invalid_thumbnail_uri);
@@ -269,30 +310,24 @@ gboolean nautilus_thumbnail_has_invalid_thumbnail (NautilusFile *file,
 
 /* routine that takes a uri of a large image file and returns the uri of its corresponding thumbnail.
    If no thumbnail is available, put the image on the thumbnail queue so one is eventually made. */
-/* FIXME bugzilla.eazel.com 642: 
+/* FIXME bugzilla.gnome.org 40642: 
  * Most of this thumbnail machinery belongs in NautilusFile, not here.
  */
 
 char *
-nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
+nautilus_get_thumbnail_uri (NautilusFile *file)
 {
 	GnomeVFSResult result;
-	GnomeVFSURI *temp_uri;
 	char *thumbnail_uri;
 	char *file_uri;
-	gboolean can_write, uri_is_local;
+	gboolean can_write;
 	NautilusFile *destination_file;
 	gboolean local_flag = TRUE;
 	gboolean  remake_thumbnail = FALSE;
 	
 	file_uri = nautilus_file_get_uri (file);
-	
-	/* compose the uri for the thumbnail locally */
-	temp_uri = gnome_vfs_uri_new (file_uri);
-	uri_is_local = gnome_vfs_uri_is_local (temp_uri);
-	gnome_vfs_uri_unref (temp_uri);
-	
-	thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, uri_is_local, anti_aliased, TRUE);
+		
+	thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, TRUE, TRUE);
 		
 	/* if the thumbnail file already exists locally, simply return the uri */
 	
@@ -318,7 +353,7 @@ nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
 	/* now try it globally */
 	if (!remake_thumbnail) {
 		g_free (thumbnail_uri);
-		thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, FALSE, anti_aliased, TRUE);
+		thumbnail_uri = make_thumbnail_uri (file_uri, FALSE, FALSE, TRUE);
 		
 		/* if the thumbnail file already exists in the common area,  return that uri, */
 		/* the uri is guaranteed to be local */
@@ -343,9 +378,9 @@ nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
         /* make the thumbnail directory if necessary, at first try it locally */
 	g_free (thumbnail_uri);
 	local_flag = TRUE;
-	thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, anti_aliased, TRUE);
+	thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, TRUE);
 				
-	/* FIXME bugzilla.eazel.com 3137: more potentially losing
+	/* FIXME bugzilla.gnome.org 43137: more potentially losing
 	   synch I/O - this could be remote */
 
 	result = gnome_vfs_make_directory (thumbnail_uri, THUMBNAIL_DIR_PERMISSIONS);
@@ -362,7 +397,7 @@ nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
 	if (!can_write || (result != GNOME_VFS_OK && result != GNOME_VFS_ERROR_FILE_EXISTS)) {	
 		g_free (thumbnail_uri);
 		local_flag = FALSE;
-		thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, anti_aliased, TRUE);
+		thumbnail_uri = make_thumbnail_uri (file_uri, TRUE, local_flag, TRUE);
 		/* this is guaranteed to be local, so synch I/O can be tolerated here */
 		result = gnome_vfs_make_directory (thumbnail_uri, THUMBNAIL_DIR_PERMISSIONS);	
 	}
@@ -370,21 +405,14 @@ nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
 	/* the thumbnail needs to be created (or recreated), so add an entry to the thumbnail list */
  
 	if (result != GNOME_VFS_OK && result != GNOME_VFS_ERROR_FILE_EXISTS) {
-
 		g_warning ("error when making thumbnail directory %d, for %s", result, thumbnail_uri);	
 	} else {
 		NautilusThumbnailInfo *info = g_new0 (NautilusThumbnailInfo, 1);
 		info->thumbnail_uri = file_uri;
 		info->is_local = local_flag;
-		info->anti_aliased = anti_aliased;
 		
-		if (thumbnails != NULL) {
-			if (g_list_find_custom (thumbnails, info, compare_thumbnail_info) == NULL) {
-				thumbnails = g_list_append (thumbnails, info);
-			}
-		} else {
-			thumbnails = g_list_alloc ();
-			thumbnails->data = info;
+		if (g_list_find_custom (thumbnails, info, compare_thumbnail_info) == NULL) {
+			thumbnails = g_list_append (thumbnails, info);
 		}
 	
 		if (thumbnail_timeout_id == 0) {
@@ -399,21 +427,17 @@ nautilus_get_thumbnail_uri (NautilusFile *file, gboolean anti_aliased)
 	return NULL;
 }
 
-static void 
-nautilus_update_thumbnail_file_renamed_one (const char *old_file_name, const char *new_file_name,
-	gboolean anti_aliased)
+void
+nautilus_update_thumbnail_file_renamed (const char *old_file_uri, const char *new_file_uri)
 {
-	GnomeVFSURI *uri;
 	gboolean is_local;
 	char *old_thumbnail_uri, *new_thumbnail_uri;
 	
-	uri = gnome_vfs_uri_new (old_file_name);
-	is_local = gnome_vfs_uri_is_local (uri);
-	gnome_vfs_uri_unref (uri);
+	is_local = uri_is_local (old_file_uri);
 	
-	old_thumbnail_uri = make_thumbnail_uri (old_file_name, FALSE, is_local, anti_aliased, FALSE);
+	old_thumbnail_uri = make_thumbnail_uri (old_file_uri, FALSE, is_local, FALSE);
 	if (old_thumbnail_uri != NULL && vfs_file_exists (old_thumbnail_uri)) {
-		new_thumbnail_uri = make_thumbnail_uri (new_file_name, FALSE, is_local, anti_aliased, FALSE);
+		new_thumbnail_uri = make_thumbnail_uri (new_file_uri, FALSE, is_local, FALSE);
 
 		g_assert (new_thumbnail_uri != NULL);
 
@@ -425,27 +449,12 @@ nautilus_update_thumbnail_file_renamed_one (const char *old_file_name, const cha
 	g_free (old_thumbnail_uri);
 }
 
-/* update the thumbnail after the thumbnailed file got renamed */
 void 
-nautilus_update_thumbnail_file_renamed (const char *old_file_name, const char *new_file_name)
+nautilus_remove_thumbnail_for_file (const char *old_file_uri)
 {
-	/* rename both the AA and non-AA thumbnails, if they exist */
-	nautilus_update_thumbnail_file_renamed_one (old_file_name, new_file_name, FALSE);
-	nautilus_update_thumbnail_file_renamed_one (old_file_name, new_file_name, TRUE);
-}
-
-static void 
-nautilus_remove_thumbnail_for_file_one (const char *old_file_name, gboolean anti_aliased)
-{
-	GnomeVFSURI *uri;
-	gboolean is_local;
 	char *thumbnail_uri;
 	
-	uri = gnome_vfs_uri_new (old_file_name);
-	is_local = gnome_vfs_uri_is_local (uri);
-	gnome_vfs_uri_unref (uri);
-	
-	thumbnail_uri = make_thumbnail_uri (old_file_name, FALSE, is_local, anti_aliased, FALSE);
+	thumbnail_uri = make_thumbnail_uri (old_file_uri, FALSE, uri_is_local (old_file_uri), FALSE);
 	if (thumbnail_uri != NULL && vfs_file_exists (thumbnail_uri)) {
 		gnome_vfs_unlink (thumbnail_uri);
 	}
@@ -453,15 +462,6 @@ nautilus_remove_thumbnail_for_file_one (const char *old_file_name, gboolean anti
 	g_free (thumbnail_uri);
 }
 
-/* remove the thumbnail after the thumbnailed file got deleted */
-void 
-nautilus_remove_thumbnail_for_file (const char *old_file_name)
-{
-	/* remove both the AA and non-AA thumbnails, if they exist */
-	nautilus_remove_thumbnail_for_file_one (old_file_name, FALSE);
-	nautilus_remove_thumbnail_for_file_one (old_file_name, TRUE);
-}
-
 /* check_for_thumbnails is a utility that checks to see if the current thumbnail task has terminated.
    If it has, remove the thumbnail info from the queue and return TRUE; if it's still in progress, return FALSE.
 */
@@ -486,8 +486,7 @@ check_for_thumbnails (void)
 		/* the thumbnail task has completed, so update the current entry from the list */
 		file = nautilus_file_get (info->thumbnail_uri);
 
-		current_thumbnail = make_thumbnail_uri (info->thumbnail_uri, FALSE, info->is_local,
-			info->anti_aliased, TRUE);
+		current_thumbnail = make_thumbnail_uri (info->thumbnail_uri, FALSE, info->is_local, TRUE);
 		
 		/* if a thumbnail wasn't successfully made, create a placeholder to flag that we tried */
 		need_update = TRUE;
@@ -528,28 +527,12 @@ check_for_thumbnails (void)
 }
 
 /* make_thumbnails is invoked periodically as a timer task to launch a task to make thumbnails */
-
-static GdkPixbuf*
-load_thumbnail_frame (gboolean anti_aliased)
-{
-	char *image_path;
-	GdkPixbuf *frame_image;
-				
-	/* load the thumbnail frame */
-	image_path = nautilus_theme_get_image_path (anti_aliased ? "thumbnail_frame.aa.png" : "thumbnail_frame.png");
-	frame_image = gdk_pixbuf_new_from_file (image_path);
-	g_free (image_path);
-	return frame_image;
-}
-
 static int
 make_thumbnails (gpointer data)
 {
 	NautilusThumbnailInfo *info;
 	GList *next_thumbnail = thumbnails;
-	GdkPixbuf *scaled_image, *framed_image, *thumbnail_image_frame;
-	char *frame_offset_str;
-	int left_offset, top_offset, right_offset, bottom_offset;
+	GdkPixbuf *scaled_image;
 	
 	/* if the queue is empty, there's nothing more to do */
 	if (next_thumbnail == NULL) {
@@ -571,8 +554,7 @@ make_thumbnails (gpointer data)
 			
 		/* First, compute the path name of the target thumbnail */
 		g_free (new_thumbnail_uri);
-		new_thumbnail_uri = make_thumbnail_uri (info->thumbnail_uri, FALSE, info->is_local,
-							 info->anti_aliased, TRUE);
+		new_thumbnail_uri = make_thumbnail_uri (info->thumbnail_uri, FALSE, info->is_local, TRUE);
 		
 		/* fork a task to make the thumbnail, using gdk-pixbuf to do the scaling */
 		if (!(info->thumbnail_task = fork())) {
@@ -608,43 +590,18 @@ make_thumbnails (gpointer data)
 			}
 			nautilus_file_unref (file);
 			
-			if (full_size_image != NULL) {				
-				thumbnail_image_frame = load_thumbnail_frame (info->anti_aliased);
-									
+			if (full_size_image != NULL) {													
 				/* scale the content image as necessary */	
 				scaled_image = eel_gdk_pixbuf_scale_down_to_fit (full_size_image, 96, 96);	
 				gdk_pixbuf_unref (full_size_image);
 				
-				/* embed the content image in the frame, if necessary  */
-				if (file_size > SELF_THUMBNAIL_SIZE_THRESHOLD) {
-
-					frame_offset_str = nautilus_theme_get_theme_data ("thumbnails", "FRAME_OFFSETS");
-					if (frame_offset_str != NULL) {
-						sscanf (frame_offset_str," %d , %d , %d , %d %*s",
-							&left_offset, &top_offset, &right_offset, &bottom_offset);
-					} else {
-						/* use nominal values since the info in the theme couldn't be found */
-						left_offset = 3; top_offset = 3;
-						right_offset = 6; bottom_offset = 6;
-					}
-					
-					framed_image = eel_embed_image_in_frame (scaled_image, thumbnail_image_frame,
-										 left_offset, top_offset, right_offset, bottom_offset);
-					g_free (frame_offset_str);
-				
-					gdk_pixbuf_unref (scaled_image);
-					gdk_pixbuf_unref (thumbnail_image_frame);
-				} else {
-					framed_image = scaled_image;
-				}
-				
 				thumbnail_path = gnome_vfs_get_local_path_from_uri (new_thumbnail_uri);
 				if (thumbnail_path == NULL
-				    || !eel_gdk_pixbuf_save_to_file (framed_image, thumbnail_path)) {
+				    || !eel_gdk_pixbuf_save_to_file (scaled_image, thumbnail_path)) {
 					g_warning ("error saving thumbnail %s", thumbnail_path);
 				}
 				g_free (thumbnail_path);
-				gdk_pixbuf_unref (framed_image);
+				gdk_pixbuf_unref (scaled_image);
 			} else {
 				/* gdk-pixbuf couldn't load the image, so trying using ImageMagick */
 				char *temp_str;
@@ -672,3 +629,98 @@ make_thumbnails (gpointer data)
 	
 	return TRUE;  /* we're not done yet */
 }
+
+
+/* Here is a heuristic compatibility routine to determine if a pixbuf
+ * already has a frame around it or not.
+ *
+ * This only happens with thumbnails generated by earlier versions of
+ * Nautilus, which used a fixed frame, so we can test for a few pixels
+ * to detect it. This is biased toward being quick and saying yes,
+ * since it's not that big a deal if we're wrong, and it looks better
+ * to have no frame than two frames.
+ */
+
+static gboolean
+pixel_matches_value (const guchar *pixels, guchar value)
+{
+	g_return_val_if_fail (pixels != NULL, FALSE);
+
+	return pixels[0] == value
+		&& pixels[1] == value
+		&& pixels[2] == value;
+}
+
+static gboolean
+pixbuf_is_framed (GdkPixbuf *pixbuf)
+{
+	const guchar *pixels;
+	int row_stride;
+
+	g_return_val_if_fail (pixbuf != NULL, FALSE);
+	
+	if (gdk_pixbuf_get_height (pixbuf) < 6
+	    || gdk_pixbuf_get_width (pixbuf) < 6
+	    || gdk_pixbuf_get_n_channels (pixbuf) != 4) {
+		return FALSE;
+	}
+
+	pixels = gdk_pixbuf_get_pixels (pixbuf);
+	row_stride = gdk_pixbuf_get_rowstride (pixbuf);
+
+	g_assert (row_stride >= 12);
+
+	return     pixel_matches_value (pixels,                      0xFF)
+		&& pixel_matches_value (pixels +     row_stride + 4, 0x00)
+		&& pixel_matches_value (pixels + 2 * row_stride + 8, 0xBB);
+}
+
+/* routine to load an image from the passed-in path, and then embed it in
+ * a frame if necessary
+ */
+GdkPixbuf *
+nautilus_thumbnail_load_framed_image (const char *path, gboolean anti_aliased_frame)
+{
+	GdkPixbuf *pixbuf, *pixbuf_with_frame, *frame;
+	gboolean got_frame_offsets;
+	char *frame_offset_str;
+	int left_offset, top_offset, right_offset, bottom_offset;
+	char c;
+	
+	pixbuf = gdk_pixbuf_new_from_file (path);
+	if (pixbuf == NULL || pixbuf_is_framed (pixbuf)) {
+		return pixbuf;
+	}
+	
+	/* The pixbuf isn't already framed (i.e., it was not made by
+	 * an old Nautilus), so we must embed it in a frame.
+	 */
+
+	frame = nautilus_icon_factory_get_thumbnail_frame (anti_aliased_frame);
+	if (frame == NULL) {
+		return pixbuf;
+	}
+	
+	got_frame_offsets = FALSE;
+	frame_offset_str = nautilus_theme_get_theme_data ("thumbnails", "FRAME_OFFSETS");
+	if (frame_offset_str != NULL) {
+		if (sscanf (frame_offset_str, " %d , %d , %d , %d %c",
+			    &left_offset, &top_offset, &right_offset, &bottom_offset, &c) == 4) {
+			got_frame_offsets = TRUE;
+		}
+		g_free (frame_offset_str);
+	}
+	if (!got_frame_offsets) {
+		/* use nominal values since the info in the theme couldn't be found */
+		left_offset = 3;
+		top_offset = 3;
+		right_offset = 6;
+		bottom_offset = 6;
+	}
+	
+	pixbuf_with_frame = eel_embed_image_in_frame
+		(pixbuf, frame,
+		 left_offset, top_offset, right_offset, bottom_offset);
+	gdk_pixbuf_unref (pixbuf);	
+	return pixbuf_with_frame;
+}
