@@ -115,6 +115,8 @@
 /* Use the "extra help items" placeholder to add help-related items */
 #define NAUTILUS_MENU_PATH_EXTRA_HELP_ITEMS_PLACEHOLDER	"/menu/Help/Extra Help Items"
 
+/* This holds the zooming-related items in the context menu */
+#define NAUTILUS_POPUP_PATH_ZOOM_ITEMS_PLACEHOLDER	"/popups/background/Zoom Items"
 
 /* Components can use these paths with BonoboUIHandler calls to
  * locate toolbars and toolbar items for the purpose of merging.
