@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Authors: Darin Adler <darin@eazel.com>
+ * Authors: Darin Adler <darin@bentspoon.com>
  */
 
 /* nautilus-desktop-window.c
@@ -33,12 +33,13 @@
 #include <libgnomeui/gnome-winhints.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-gtk-extensions.h>
-#include <libnautilus-extensions/nautilus-file-utilities.h>
-#include <libnautilus-extensions/nautilus-link.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-gtk-extensions.h>
+#include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-link.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtklayout.h>
 
 struct NautilusDesktopWindowDetails {
 	GList *unref_list;
@@ -48,15 +49,20 @@ static void nautilus_desktop_window_initialize_class (NautilusDesktopWindowClass
 static void nautilus_desktop_window_initialize       (NautilusDesktopWindow      *window);
 static void destroy                                  (GtkObject                  *object);
 static void realize                                  (GtkWidget                  *widget);
+static void map                                      (GtkWidget                  *widget);
 static void real_add_current_location_to_history_list (NautilusWindow		 *window);
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusDesktopWindow, nautilus_desktop_window, NAUTILUS_TYPE_WINDOW)
+
+static void set_wmspec_desktop_hint                   (GdkWindow *window);
+
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusDesktopWindow, nautilus_desktop_window, NAUTILUS_TYPE_WINDOW)
 
 static void
 nautilus_desktop_window_initialize_class (NautilusDesktopWindowClass *klass)
 {
 	GTK_OBJECT_CLASS (klass)->destroy = destroy;
 	GTK_WIDGET_CLASS (klass)->realize = realize;
+	GTK_WIDGET_CLASS (klass)->map = map;
 	NAUTILUS_WINDOW_CLASS (klass)->add_current_location_to_history_list 
 		= real_add_current_location_to_history_list;
 }
@@ -66,7 +72,7 @@ nautilus_desktop_window_initialize (NautilusDesktopWindow *window)
 {
 	window->details = g_new0 (NautilusDesktopWindowDetails, 1);
 
-	/* FIXME bugzilla.eazel.com 1251: 
+	/* FIXME bugzilla.gnome.org 41251: 
 	 * Although Havoc had this call to set_default_size in
 	 * his code, it seems to have no effect for me. But the
 	 * set_usize below does seem to work.
@@ -110,12 +116,27 @@ nautilus_desktop_window_delete_event (NautilusDesktopWindow *window)
 	return TRUE;
 }
 
+void
+nautilus_desktop_window_update_directory (NautilusDesktopWindow *window)
+{
+	char *desktop_directory_path;
+	char *desktop_directory_uri;
+
+	g_assert (NAUTILUS_IS_DESKTOP_WINDOW (window));
+
+	desktop_directory_path = nautilus_get_desktop_directory ();
+	
+	desktop_directory_uri = gnome_vfs_get_uri_from_local_path (desktop_directory_path);
+	g_free (desktop_directory_path);
+	window->affect_desktop_on_next_location_change = TRUE;
+	nautilus_window_go_to (NAUTILUS_WINDOW (window), desktop_directory_uri);
+	g_free (desktop_directory_uri);
+}
+
 NautilusDesktopWindow *
 nautilus_desktop_window_new (NautilusApplication *application)
 {
 	NautilusDesktopWindow *window;
-	char *desktop_directory_path;
-	char *desktop_directory_uri;
 
 	window = NAUTILUS_DESKTOP_WINDOW
 		(gtk_widget_new (nautilus_desktop_window_get_type(),
@@ -129,16 +150,11 @@ nautilus_desktop_window_new (NautilusApplication *application)
 	gtk_signal_connect (GTK_OBJECT (window), "realize", GTK_SIGNAL_FUNC (nautilus_desktop_window_realized), NULL);
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event", GTK_SIGNAL_FUNC (nautilus_desktop_window_delete_event), NULL);
 
-	desktop_directory_path = nautilus_get_desktop_directory ();
-	
 	/* Point window at the desktop folder.
 	 * Note that nautilus_desktop_window_initialize is too early to do this.
 	 */
-	desktop_directory_uri = gnome_vfs_get_uri_from_local_path (desktop_directory_path);
-	g_free (desktop_directory_path);
-	nautilus_window_go_to (NAUTILUS_WINDOW (window), desktop_directory_uri);
-	g_free (desktop_directory_uri);
-	
+	nautilus_desktop_window_update_directory (window);
+
 	gtk_widget_show (GTK_WIDGET (window));
 
 	return window;
@@ -153,10 +169,114 @@ destroy (GtkObject *object)
 
 	gdk_property_delete (NULL, gdk_atom_intern ("NAUTILUS_DESKTOP_WINDOW_ID", TRUE));
 
-	nautilus_gtk_object_list_free (window->details->unref_list);
+	eel_gtk_object_list_free (window->details->unref_list);
 	g_free (window->details);
 
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+}
+
+static void
+set_gdk_window_background (GdkWindow *window,
+			   gboolean   have_pixel,
+			   Pixmap     pixmap,
+			   gulong     pixel)
+{
+	Window w;
+
+	w = GDK_WINDOW_XWINDOW (window);
+
+	if (pixmap != None) {
+		XSetWindowBackgroundPixmap (GDK_DISPLAY (), w,
+					    pixmap);
+	} else if (have_pixel) {
+		XSetWindowBackground (GDK_DISPLAY (), w,
+				      pixel);
+	} else {
+		XSetWindowBackgroundPixmap (GDK_DISPLAY (), w,
+					    None);
+	}
+}
+
+static void
+set_window_background (GtkWidget *widget,
+		       gboolean   already_have_root_bg,
+		       gboolean   have_pixel,
+		       Pixmap     pixmap,
+		       gulong     pixel)
+{
+	GdkAtom type;
+	gulong nitems, bytes_after;
+	gint format;
+	guchar *data;
+	
+	/* Set the background to show the root window to avoid a flash that
+	 * would otherwise occur.
+	 */
+
+	if (GTK_IS_WINDOW (widget)) {
+		gtk_widget_set_app_paintable (widget, TRUE);
+	}
+	
+	if (!already_have_root_bg) {
+		have_pixel = FALSE;
+		already_have_root_bg = TRUE;
+		
+		/* We want to do this round-trip-to-server work only
+		 * for the first invocation, not on recursions
+		 */
+		
+		XGetWindowProperty (GDK_DISPLAY (), GDK_ROOT_WINDOW (),
+				    gdk_atom_intern ("_XROOTPMAP_ID", FALSE),
+				    0L, 1L, False, XA_PIXMAP,
+				    &type, &format, &nitems, &bytes_after,
+				    &data);
+  
+		if (type == XA_PIXMAP) {
+			if (format == 32 && nitems == 1 && bytes_after == 0) {
+				pixmap = *(Pixmap *) data;
+			}
+  
+			XFree (data);
+		}
+
+		if (pixmap == None) {
+			XGetWindowProperty (GDK_DISPLAY (), GDK_ROOT_WINDOW (),
+					    gdk_atom_intern ("_XROOTCOLOR_PIXEL", FALSE),
+					    0L, 1L, False, AnyPropertyType,
+					    &type, &format, &nitems, &bytes_after,
+					    &data);
+			
+			if (type != None) {
+				if (format == 32 && nitems == 1 && bytes_after == 0) {
+					pixel = *(gulong *) data;
+					have_pixel = TRUE;
+				}
+				
+				XFree (data);
+			}
+		}
+	}
+	
+	set_gdk_window_background (widget->window,
+				   have_pixel, pixmap, pixel);
+	
+	if (GTK_IS_BIN (widget) &&
+	    GTK_BIN (widget)->child) {
+		/* Ensure we're realized */
+		gtk_widget_realize (GTK_BIN (widget)->child);
+		
+		set_window_background (GTK_BIN (widget)->child,
+				       already_have_root_bg, have_pixel,
+				       pixmap, pixel);
+	}
+
+	/* For both parent and child, if it's a layout then set on the
+	 * bin window as well.
+	 */
+	if (GTK_IS_LAYOUT (widget))
+		set_gdk_window_background (GTK_LAYOUT (widget)->bin_window,
+					   have_pixel,
+					   pixmap, pixel);
 }
 
 static void
@@ -171,28 +291,29 @@ realize (GtkWidget *widget)
 			      | GDK_KEY_PRESS_MASK | GDK_KEY_PRESS_MASK);
 			      
 	/* Do the work of realizing. */
-	NAUTILUS_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
-
-	/* FIXME bugzilla.eazel.com 1253: 
-	 * Looking at the gnome_win_hints implementation,
-	 * it looks like you can call these with an unmapped window,
-	 * but when I tried doing it in initialize it didn't work.
-	 * We'd like to set these earlier so the window doesn't show
-	 * up in front of everything before going to the back.
-	 */
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
 
+	/* This is the new way to set up the desktop window */
+	set_wmspec_desktop_hint (widget->window);
+	
+	/* FIXME all this gnome_win_hints stuff is legacy cruft */
+	
 	/* Put this window behind all the others. */
 	gnome_win_hints_set_layer (widget, WIN_LAYER_DESKTOP);
-
+	
 	/* Make things like the task list ignore this window and make
 	 * it clear that it it's at its full size.
+	 *
+	 * We originally included WIN_STATE_HIDDEN here, but IceWM
+	 * interprets that (wrongly, imho) as meaning `don't display
+	 * this window'. Not including this bit seems to make
+	 * no difference though, so..
 	 */
 	gnome_win_hints_set_state (widget,
 				   WIN_STATE_STICKY
 				   | WIN_STATE_MAXIMIZED_VERT
 				   | WIN_STATE_MAXIMIZED_HORIZ
 				   | WIN_STATE_FIXED_POSITION
-				   | WIN_STATE_HIDDEN
 				   | WIN_STATE_ARRANGE_IGNORE);
 
 	/* Make sure that focus, and any window lists or task bars also
@@ -203,7 +324,7 @@ realize (GtkWidget *widget)
 				   | WIN_HINTS_SKIP_TASKBAR
 				   | WIN_HINTS_SKIP_FOCUS);
 
-	/* FIXME bugzilla.eazel.com 1255: 
+	/* FIXME bugzilla.gnome.org 41255: 
 	 * Should we do a gdk_window_move_resize here, in addition to
 	 * the calls in initialize above that set the size?
 	 */
@@ -219,6 +340,19 @@ realize (GtkWidget *widget)
         gdk_window_set_functions (widget->window, 0);
 }
 
+static void
+map (GtkWidget *widget)
+{
+	NautilusDesktopWindow *window;
+
+	window = NAUTILUS_DESKTOP_WINDOW (widget);
+	
+	set_window_background (widget, FALSE, FALSE, None, 0);
+	
+	/* Chain up to realize our children */
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, map, (widget));
+}
+
 static void
 real_add_current_location_to_history_list (NautilusWindow *window)
 {
@@ -226,3 +360,21 @@ real_add_current_location_to_history_list (NautilusWindow *window)
 	 * show up in the history list.
 	 */
 }
+
+static void
+set_wmspec_desktop_hint (GdkWindow *window)
+{
+        Atom atom;
+        
+        atom = XInternAtom (gdk_display,
+                            "_NET_WM_WINDOW_TYPE_DESKTOP",
+                            False);
+
+        XChangeProperty (GDK_WINDOW_XDISPLAY (window),
+                         GDK_WINDOW_XWINDOW (window),
+                         XInternAtom (gdk_display,
+                                      "_NET_WM_WINDOW_TYPE",
+                                      False),
+                         XA_ATOM, 32, PropModeReplace,
+                         (guchar *)&atom, 1);
+}
