@@ -155,7 +155,7 @@ druid_cancel (GtkWidget *druid)
 {
 	gtk_widget_destroy (gtk_widget_get_toplevel (druid));
 
-	/* FIXME bugzilla.eazel.com 5050: Why _exit instead of a plain exit? It might be OK
+	/* FIXME bugzilla.gnome.org 45050: Why _exit instead of a plain exit? It might be OK
 	 * to do nothing here now that Nautilus knows to quit when
 	 * windows go away.
 	 */
@@ -164,49 +164,39 @@ druid_cancel (GtkWidget *druid)
 
 /* handle the final page finishing  */
 
-static void
-druid_set_first_time_file_flag (void)
+void
+nautilus_set_first_time_file_flag (void)
 {
 	FILE *stream;
 	char *user_directory, *druid_flag_file_name;
+	const char * const blurb =
+		_("Existence of this file indicates that the Nautilus configuration druid\n"
+		  "has been presented.\n\n"
+		  "You can manually erase this file to present the druid again.\n");
 	
 	user_directory = nautilus_get_user_directory ();
-	druid_flag_file_name = g_strdup_printf ("%s/%s",
-						user_directory,
-						"first-time-flag");
+	druid_flag_file_name = nautilus_make_path (user_directory, "first-time-flag");
 	g_free (user_directory);
-
 		
 	stream = fopen (druid_flag_file_name, "w");
-	if (stream) {
-		const char *blurb =
-			_("Existence of this file indicates that the Nautilus configuration druid\n"
-				"has been presented.\n\n"
-				"You can manually erase this file to present the druid again.\n\n");
-			
-			fwrite (blurb, sizeof (char), strlen (blurb), stream);
-			fclose (stream);
+	if (stream != NULL) {
+		fwrite (blurb, sizeof (char), strlen (blurb), stream);
+		fclose (stream);
 	}
-	
 	g_free (druid_flag_file_name);
 }
 
 static void
 druid_finished (GtkWidget *druid_page)
 {
-	char *user_main_directory;
 	const char *signup_uris[3];
 	
 	
 	/* Hide druid so we don't have a blocked dialog visible while we process the startup tasks. */
-	gtk_widget_hide_all (gtk_widget_get_toplevel (druid_page));
-	
-	user_main_directory = nautilus_get_user_main_directory ();
-
-	g_free (user_main_directory);
+	gtk_widget_hide_all (gtk_widget_get_toplevel (druid_page));	
 
 	/* write out the first time file to indicate that we've successfully traversed the druid */
-	druid_set_first_time_file_flag ();
+	nautilus_set_first_time_file_flag ();
 
 	/* Do the user level config */
 	eel_preferences_set_user_level (current_user_level);
@@ -217,7 +207,7 @@ druid_finished (GtkWidget *druid_page)
 	 * we don't want Nautilus to hang indefinitely trying to resolve
 	 * an HTTP address.
 	 */
-	/* FIXME bugzilla.eazel.com 5051: Perhaps we can fix the underlying problem instead of
+	/* FIXME bugzilla.gnome.org 45051: Perhaps we can fix the underlying problem instead of
 	 * having this hack here to guess whether the network is broken.
 	 */
 	if (Untested == network_status) {
@@ -240,7 +230,7 @@ druid_finished (GtkWidget *druid_page)
 		gtk_idle_add (convert_gmc_desktop_icons, NULL);
 	}
 #endif
-	
+ 	
 	/* Time to start. Hooray! */
 	nautilus_application_startup (save_application, FALSE, FALSE, draw_desktop, 
 				      FALSE, FALSE, NULL, (signup_uris[0] != NULL) ? signup_uris : NULL);
@@ -750,7 +740,7 @@ next_update_page_callback (GtkWidget *button, GnomeDruid *druid)
 {
 	if (last_update_choice == 0) {
 		/* initiate the file transfer and launch a timer task to track feedback */
-		/* FIXME bugzilla.eazel.com 5053: There's no timer task! */
+		/* FIXME bugzilla.gnome.org 45053: There's no timer task! */
 		initiate_file_download (druid);
 		
 		/* return FALSE to display the feedback page */
@@ -900,7 +890,7 @@ set_up_gmc_transition_page (NautilusDruidPageEazel *page)
 	gtk_signal_connect (GTK_OBJECT (checkbox), "toggled", GTK_SIGNAL_FUNC (transition_value_changed), &transfer_gmc_icons);
 
 #if 0
-	/* This option is currently disabled, per bugzilla.eazel.com 7557 */
+	/* This option is currently disabled, per bugzilla.gnome.org 47557 */
 
 	checkbox = gtk_check_button_new_with_label (_("Launch Nautilus when GNOME starts up."));
 	gtk_box_pack_start (GTK_BOX (main_box), checkbox, FALSE, FALSE, 0);
@@ -1265,10 +1255,10 @@ initiate_file_download (GnomeDruid *druid)
 	/* Cancel any download already in progress. */
 	gtk_object_remove_data (GTK_OBJECT (druid), READ_FILE_HANDLE_TAG);
 			
-	/* FIXME bugzilla.eazel.com 5054: We might hang here for a while; if we do, we don't want
+	/* FIXME bugzilla.gnome.org 45054: We might hang here for a while; if we do, we don't want
 	 * the user to get forced through the druid again
 	 */
-	druid_set_first_time_file_flag ();
+	nautilus_set_first_time_file_flag ();
 
 	/* We need to exercise the main loop so that gnome-vfs can get its
 	 * gconf callback for the HTTP proxy autoconfiguration case.
@@ -1370,7 +1360,7 @@ set_http_proxy (const char *proxy_url)
  * reads newline (or CR) or EOF terminated line from stream, allocating the return
  * buffer as appropriate
  **/
-/* FIXME bugzilla.eazel.com 5055: Belongs in a library, not here. */
+/* FIXME bugzilla.gnome.org 45055: Belongs in a library, not here. */
 static char * 
 getline_dup (FILE* stream)
 {
@@ -1459,7 +1449,7 @@ load_netscape_proxy_settings (void)
 		} else if ( NULL != (current = strstr (line, "\"network.proxy.http_port\""))) {
 			current += strlen ("\"network.proxy.http_port\"");
 
-			while ( *current && !isdigit(*current)) {
+			while (*current && !isdigit ((guchar) *current)) {
 				current++;
 			}
 
@@ -1473,7 +1463,7 @@ load_netscape_proxy_settings (void)
 			/* Proxy type must equal '1' */
 			current += strlen ("\"network.proxy.type\"");
 
-			while ( *current && !isdigit(*current)) {
+			while (*current && !isdigit ((guchar) *current)) {
 				current++;
 			}
 
