@@ -3,7 +3,7 @@
 /*
  * Nautilus
  *
- * Copyright (C) 2000 Eazel, Inc.
+ * Copyright (C) 2000, 2001 Eazel, Inc.
  *
  * Nautilus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,43 +22,54 @@
  * Author: Andy Hertzfeld <andy@eazel.com>
  */
 
-/* This is the index title widget, which is the title part of the index panel
- */
+/* This is the sidebar title widget, which is the title part of the sidebar. */
 
 #include <config.h>
 #include "nautilus-sidebar-title.h"
+
 #include "nautilus-sidebar.h"
+#include "nautilus-window.h"
 
 #include <ctype.h>
-#include <string.h>
-#include <math.h>
+#include <bonobo/bonobo-property-bag-client.h>
+#include <bonobo/bonobo-exception.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkpixmap.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtkwidget.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
-#include <libnautilus-extensions/nautilus-background.h>
-#include <libnautilus-extensions/nautilus-file-attributes.h>
-#include <libnautilus-extensions/nautilus-gdk-extensions.h>
-#include <libnautilus-extensions/nautilus-gdk-font-extensions.h>
-#include <libnautilus-extensions/nautilus-gdk-pixbuf-extensions.h>
-#include <libnautilus-extensions/nautilus-glib-extensions.h>
-#include <libnautilus-extensions/nautilus-global-preferences.h>
-#include <libnautilus-extensions/nautilus-gtk-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-icon-factory.h>
-#include <libnautilus-extensions/nautilus-metadata.h>
-#include <libnautilus-extensions/nautilus-search-uri.h>
-#include <libnautilus-extensions/nautilus-font-factory.h>
-#include <libnautilus-extensions/nautilus-string.h>
-#include <libnautilus-extensions/nautilus-theme.h>
-#include <libnautilus-extensions/nautilus-label-with-background.h>
-#include <libnautilus-extensions/nautilus-image-with-background.h>
+#include <eel/eel-background.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
+#include <libnautilus-private/nautilus-font-factory.h>
+#include <eel/eel-gdk-extensions.h>
+#include <eel/eel-gdk-font-extensions.h>
+#include <eel/eel-gdk-pixbuf-extensions.h>
+#include <eel/eel-glib-extensions.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <libnautilus-private/nautilus-icon-factory.h>
+#include <eel/eel-image-with-background.h>
+#include <eel/eel-label-with-background.h>
+#include <libnautilus-private/nautilus-metadata.h>
+#include <libnautilus-private/nautilus-search-uri.h>
+#include <eel/eel-string.h>
+#include <libnautilus-private/nautilus-theme.h>
+#include <math.h>
+#include <string.h>
 
 /* maximum allowable size to be displayed as the title */
-#define MAX_TITLE_SIZE 256
+#define MAX_TITLE_SIZE 		256
+#define MINIMUM_INFO_WIDTH	32
+#define SIDEBAR_INFO_MARGIN	4
+
+#define MORE_INFO_FONT_SIZE 	 12
+#define MIN_TITLE_FONT_SIZE 	 12
+#define MAX_TITLE_FONT_SIZE 	 20
+#define TITLE_PADDING		  4
 
 static void                nautilus_sidebar_title_initialize_class (NautilusSidebarTitleClass *klass);
 static void                nautilus_sidebar_title_destroy          (GtkObject                 *object);
@@ -69,13 +80,17 @@ static void                nautilus_sidebar_title_theme_changed    (gpointer
 static void                update_icon                             (NautilusSidebarTitle      *sidebar_title);
 static GtkWidget *         sidebar_title_create_title_label        (void);
 static GtkWidget *         sidebar_title_create_more_info_label    (void);
-static void                update_all_cover   			   (gpointer                   callback_data);
 static void		   update_all 				   (NautilusSidebarTitle      *sidebar_title);
-static NautilusBackground *nautilus_sidebar_title_background       (NautilusSidebarTitle      *sidebar_title);
+static void		   update_title_font			   (NautilusSidebarTitle      *sidebar_title);
+static EelBackground 	  *nautilus_sidebar_title_background       (NautilusSidebarTitle      *sidebar_title);
+
+static const char *non_smooth_font_name;
 
 struct NautilusSidebarTitleDetails {
 	NautilusFile		*file;
-	guint			file_changed_connection;
+	guint			 file_changed_connection;
+	gboolean                 monitoring_count;
+
 	char			*title_text;
 	GtkWidget		*icon;
 	GtkWidget		*title_label;
@@ -83,11 +98,11 @@ struct NautilusSidebarTitleDetails {
 	GtkWidget		*emblem_box;
 	GtkWidget		*notes;
 
-	int			shadow_offset;
-	gboolean		determined_icon;
+	int			 shadow_offset;
+	gboolean		 determined_icon;
 };
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusSidebarTitle, nautilus_sidebar_title, gtk_vbox_get_type ())
+EEL_DEFINE_CLASS_BOILERPLATE (NautilusSidebarTitle, nautilus_sidebar_title, gtk_vbox_get_type ())
 
 static void
 nautilus_sidebar_title_initialize_class (NautilusSidebarTitleClass *class)
@@ -100,10 +115,13 @@ nautilus_sidebar_title_initialize_class (NautilusSidebarTitleClass *class)
 	
 	object_class->destroy = nautilus_sidebar_title_destroy;
 	widget_class->size_allocate = nautilus_sidebar_title_size_allocate;
+
+	eel_preferences_add_auto_string (NAUTILUS_PREFERENCES_DEFAULT_FONT,
+					 &non_smooth_font_name);
 }
 
 static void
-appearance_changed_callback (NautilusBackground *background, NautilusSidebarTitle *sidebar_title)
+appearance_changed_callback (EelBackground *background, NautilusSidebarTitle *sidebar_title)
 {
 	nautilus_sidebar_title_select_text_color (sidebar_title);
 }		
@@ -111,7 +129,7 @@ appearance_changed_callback (NautilusBackground *background, NautilusSidebarTitl
 static void
 realize_callback (NautilusSidebarTitle *sidebar_title)
 {
-	NautilusBackground *background;
+	EelBackground *background;
 	
 	background = nautilus_sidebar_title_background (sidebar_title);
 
@@ -127,24 +145,55 @@ realize_callback (NautilusSidebarTitle *sidebar_title)
 static void
 smooth_font_changed_callback (gpointer callback_data)
 {
-	NautilusScalableFont *new_font;
-	NautilusScalableFont *new_bold_font;
+	EelScalableFont *new_font;
+	EelScalableFont *new_bold_font;
 	NautilusSidebarTitle *sidebar_title;
 
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (callback_data));
 
 	sidebar_title = NAUTILUS_SIDEBAR_TITLE (callback_data);
 	
-	new_font = nautilus_global_preferences_get_smooth_font ();
-	new_bold_font = nautilus_global_preferences_get_smooth_bold_font ();
+	new_font = nautilus_global_preferences_get_default_smooth_font ();
+	new_bold_font = nautilus_global_preferences_get_default_smooth_bold_font ();
 
-	nautilus_label_set_smooth_font (NAUTILUS_LABEL (sidebar_title->details->title_label), new_bold_font);
-	nautilus_label_set_smooth_font (NAUTILUS_LABEL (sidebar_title->details->more_info_label), new_font);
+	eel_label_set_smooth_font (EEL_LABEL (sidebar_title->details->title_label), new_bold_font);
+	eel_label_set_smooth_font (EEL_LABEL (sidebar_title->details->more_info_label), new_font);
 
 	gtk_object_unref (GTK_OBJECT (new_font));
 	gtk_object_unref (GTK_OBJECT (new_bold_font));
 }
 
+static GdkFont *
+get_non_smooth_font (int font_size)
+{
+	GdkFont *result;
+
+	result = nautilus_font_factory_get_font_by_family (non_smooth_font_name, font_size);
+	g_assert (result != NULL);
+
+	return result;
+}
+
+static void
+non_smooth_font_changed_callback (gpointer callback_data)
+{
+	NautilusSidebarTitle *sidebar_title;
+	GdkFont *new_font;
+
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (callback_data));
+
+	sidebar_title = NAUTILUS_SIDEBAR_TITLE (callback_data);
+
+	/* Update the dynamically-sized title font */
+	update_title_font (sidebar_title);
+
+	/* Update the fixed-size "more info" font */
+	new_font = get_non_smooth_font (MORE_INFO_FONT_SIZE);
+	eel_gtk_widget_set_font (sidebar_title->details->more_info_label,
+				 new_font);	
+	gdk_font_unref (new_font);
+}
+
 static void
 nautilus_sidebar_title_initialize (NautilusSidebarTitle *sidebar_title)
 { 
@@ -158,7 +207,7 @@ nautilus_sidebar_title_initialize (NautilusSidebarTitle *sidebar_title)
 	gtk_signal_connect (GTK_OBJECT (sidebar_title), "realize", realize_callback, NULL);
 
 	/* Create the icon */
-	sidebar_title->details->icon = nautilus_image_new_with_background (NULL);
+	sidebar_title->details->icon = eel_image_new_with_background (NULL);
 	gtk_box_pack_start (GTK_BOX (sidebar_title), sidebar_title->details->icon, 0, 0, 0);
 	gtk_widget_show (sidebar_title->details->icon);
 
@@ -176,7 +225,7 @@ nautilus_sidebar_title_initialize (NautilusSidebarTitle *sidebar_title)
 	gtk_widget_show (sidebar_title->details->emblem_box);
 	gtk_box_pack_start (GTK_BOX (sidebar_title), sidebar_title->details->emblem_box, 0, 0, 0);
 
-	/* FIXME: This should use NautilusLabel like the other displayed text.
+	/* FIXME: This should use EelLabel like the other displayed text.
 	 * But I don't think this feature is ever used? Someone should consult
 	 * with Andy about this. (This is not the same as the info in the Notes
 	 * sidebar panel.)
@@ -188,23 +237,26 @@ nautilus_sidebar_title_initialize (NautilusSidebarTitle *sidebar_title)
 
 	/* Keep track of changes in graphics trade offs */
 	update_all (sidebar_title);
-	nautilus_preferences_add_callback (NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE, 
-					   update_all_cover, 
-					   sidebar_title);
-	nautilus_preferences_add_callback (NAUTILUS_PREFERENCES_DIRECTORY_VIEW_FONT_FAMILY,
-					   update_all_cover,
-					   sidebar_title);
-	nautilus_preferences_add_callback (NAUTILUS_PREFERENCES_DIRECTORY_VIEW_SMOOTH_FONT,
-					   smooth_font_changed_callback,
-					   sidebar_title);
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DEFAULT_FONT,
+						       non_smooth_font_changed_callback,
+						       sidebar_title,
+						       GTK_OBJECT (sidebar_title));
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
+						       smooth_font_changed_callback,
+						       sidebar_title,
+						       GTK_OBJECT (sidebar_title));
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_THEME,
+						       nautilus_sidebar_title_theme_changed,
+						       sidebar_title,
+						       GTK_OBJECT (sidebar_title));
 
-	/* set up the label colors according to the theme, and get notified of changes */
+	/* initialize the label colors & fonts */
 	nautilus_sidebar_title_theme_changed (sidebar_title);
-	nautilus_preferences_add_callback (NAUTILUS_PREFERENCES_THEME, nautilus_sidebar_title_theme_changed, sidebar_title);
+	smooth_font_changed_callback (sidebar_title);
+	non_smooth_font_changed_callback (sidebar_title);
 }
 
 /* destroy by throwing away private storage */
-
 static void
 release_file (NautilusSidebarTitle *sidebar_title)
 {
@@ -233,36 +285,22 @@ nautilus_sidebar_title_destroy (GtkObject *object)
 	g_free (sidebar_title->details->title_text);
 	g_free (sidebar_title->details);
 
-	nautilus_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME, 
-					      nautilus_sidebar_title_theme_changed, 
-					      sidebar_title);
-	nautilus_preferences_remove_callback (NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE, 
-					      update_all_cover, 
-					      sidebar_title);
-	nautilus_preferences_remove_callback (NAUTILUS_PREFERENCES_DIRECTORY_VIEW_FONT_FAMILY, 
-					      update_all_cover, 
-					      sidebar_title);
-	nautilus_preferences_remove_callback (NAUTILUS_PREFERENCES_DIRECTORY_VIEW_SMOOTH_FONT,
-					      smooth_font_changed_callback,
-					      sidebar_title);
-  	
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 /* return a new index title object */
-
 GtkWidget *
 nautilus_sidebar_title_new (void)
 {
 	return gtk_widget_new (nautilus_sidebar_title_get_type (), NULL);
 }
 
-static NautilusBackground *
+static EelBackground *
 nautilus_sidebar_title_background (NautilusSidebarTitle *sidebar_title)
 {
 	GtkWidget *widget;
 	GtkWidget *sidebar;
-	NautilusBackground *background;
+	EelBackground *background;
 
 	g_return_val_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (sidebar_title), NULL);
 	
@@ -272,11 +310,11 @@ nautilus_sidebar_title_background (NautilusSidebarTitle *sidebar_title)
 	if (widget != NULL) {
 		sidebar = widget->parent;
 		g_return_val_if_fail (NAUTILUS_IS_SIDEBAR (sidebar), NULL);
-		background = nautilus_get_widget_background (sidebar);
-		g_return_val_if_fail (NAUTILUS_IS_BACKGROUND (background), NULL);
+		background = eel_get_widget_background (sidebar);
+		g_return_val_if_fail (EEL_IS_BACKGROUND (background), NULL);
 		return background;
 	} else {
-		/* FIXME bugzilla.eazel.com 5042
+		/* FIXME bugzilla.gnome.org 45042
 		 * It would be preferable to assert widget != NULL and not have
 		 * this else case. Doing this would require us to be carful when
 		 * nautilus_sidebar_title_select_text_color is called - which would
@@ -313,7 +351,7 @@ nautilus_sidebar_title_background_is_default (NautilusSidebarTitle *sidebar_titl
 void
 nautilus_sidebar_title_select_text_color (NautilusSidebarTitle *sidebar_title)
 {
-	NautilusBackground *background;
+	EelBackground *background;
 	char *sidebar_title_color;
 	char *sidebar_info_title_color;
 	char *sidebar_title_shadow_color;
@@ -334,8 +372,8 @@ nautilus_sidebar_title_select_text_color (NautilusSidebarTitle *sidebar_title)
 		}
 		
 		if (sidebar_title_color == NULL) {
-			/* FIXME bugzilla.eazel.com 2496: for now, both the title and info colors are the same */
-			if (nautilus_background_is_dark (background)) {
+			/* FIXME bugzilla.gnome.org 42496: for now, both the title and info colors are the same */
+			if (eel_background_is_dark (background)) {
 				sidebar_title_color = g_strdup("rgb:FFFF/FFFF/FFFF");
 				sidebar_info_title_color = g_strdup("rgb:FFFF/FFFF/FFFF");
 				sidebar_title_shadow_color = g_strdup("rgb:0000/0000/0000");
@@ -354,22 +392,22 @@ nautilus_sidebar_title_select_text_color (NautilusSidebarTitle *sidebar_title)
 			}
 		}
 
-		nautilus_label_set_text_color (NAUTILUS_LABEL (sidebar_title->details->title_label),
-						       nautilus_parse_rgb_with_white_default (sidebar_title_color));
+		eel_label_set_text_color (EEL_LABEL (sidebar_title->details->title_label),
+						       eel_parse_rgb_with_white_default (sidebar_title_color));
 		
-		nautilus_label_set_smooth_drop_shadow_color (NAUTILUS_LABEL (sidebar_title->details->title_label),
-							      nautilus_parse_rgb_with_white_default (sidebar_title_shadow_color));
+		eel_label_set_smooth_drop_shadow_color (EEL_LABEL (sidebar_title->details->title_label),
+							      eel_parse_rgb_with_white_default (sidebar_title_shadow_color));
 		
-		nautilus_label_set_smooth_drop_shadow_offset (NAUTILUS_LABEL (sidebar_title->details->title_label),
+		eel_label_set_smooth_drop_shadow_offset (EEL_LABEL (sidebar_title->details->title_label),
 							       sidebar_title->details->shadow_offset);
 		
-		nautilus_label_set_text_color (NAUTILUS_LABEL (sidebar_title->details->more_info_label),
-						       nautilus_parse_rgb_with_white_default (sidebar_info_title_color));
+		eel_label_set_text_color (EEL_LABEL (sidebar_title->details->more_info_label),
+						       eel_parse_rgb_with_white_default (sidebar_info_title_color));
 		
-		nautilus_label_set_smooth_drop_shadow_color (NAUTILUS_LABEL (sidebar_title->details->more_info_label),
-							      nautilus_parse_rgb_with_white_default (sidebar_title_shadow_color));
+		eel_label_set_smooth_drop_shadow_color (EEL_LABEL (sidebar_title->details->more_info_label),
+							      eel_parse_rgb_with_white_default (sidebar_title_shadow_color));
 		
-		nautilus_label_set_smooth_drop_shadow_offset (NAUTILUS_LABEL (sidebar_title->details->more_info_label),
+		eel_label_set_smooth_drop_shadow_offset (EEL_LABEL (sidebar_title->details->more_info_label),
 							       sidebar_title->details->shadow_offset);
 		
 		g_free (sidebar_title_color);	
@@ -398,38 +436,68 @@ nautilus_sidebar_title_theme_changed (gpointer user_data)
 	nautilus_sidebar_title_select_text_color (sidebar_title);
 }
 
+/* get a property from the current content view's property bag if we can */
+static char*
+get_property_from_component (NautilusSidebarTitle *sidebar_title, const char *property)
+{
+	GtkWidget *window;
+	Bonobo_Control control;
+	CORBA_Environment ev;
+	Bonobo_PropertyBag property_bag;
+	char* icon_name;
+		
+	window = gtk_widget_get_ancestor (GTK_WIDGET (sidebar_title), NAUTILUS_TYPE_WINDOW);
+
+	if (window == NULL || NAUTILUS_WINDOW (window)->content_view == NULL) {
+		return NULL;
+	}
+
+	
+	control = nautilus_view_frame_get_control (NAUTILUS_VIEW_FRAME (NAUTILUS_WINDOW (window)->content_view));	
+	if (control == NULL) {
+		return NULL;	
+	}
+
+	CORBA_exception_init (&ev);
+	property_bag = Bonobo_Control_getProperties (control, &ev);
+	if (BONOBO_EX (&ev)) {
+		property_bag = CORBA_OBJECT_NIL;
+	}
+	CORBA_exception_free (&ev);
+
+	if (property_bag == CORBA_OBJECT_NIL) {
+		return NULL;
+	}	
+	
+	icon_name = bonobo_property_bag_client_get_value_string
+		(property_bag, property, NULL);
+	bonobo_object_release_unref (property_bag, NULL);
+
+	return icon_name;
+}
+
 /* set up the icon image */
 static void
 update_icon (NautilusSidebarTitle *sidebar_title)
 {
 	GdkPixbuf *pixbuf;
-	char *uri, *icon_path;
+	char *uri;
+	char *icon_name;
 	gboolean leave_pixbuf_unchanged;
 	
-	/* FIXME bugzilla.eazel.com 5043: currently, components can't specify their own sidebar icon.  This
-	  needs to be added to the framework, but for now we special-case some
-	  important ones here */
-
 	leave_pixbuf_unchanged = FALSE;
 	uri = NULL;
-	icon_path = NULL;
+	icon_name = NULL;
 	if (sidebar_title->details->file) {
 		uri = nautilus_file_get_uri (sidebar_title->details->file);
 	}	
-	
-	if (nautilus_istr_has_prefix (uri, "eazel:") || nautilus_istr_has_prefix (uri, "eazel-services:")) {
-		icon_path = nautilus_theme_get_image_path ("big_services_icon.png");
-	} else if (nautilus_istr_has_prefix (uri, "http:")) {
-		icon_path = nautilus_theme_get_image_path ("i-web-72.png");
-	} else if (nautilus_istr_has_prefix (uri, "man:")) {
-		icon_path = nautilus_theme_get_image_path ("manual.png");
-	} else if (nautilus_istr_has_prefix (uri, "hardware:")) {
-		icon_path = nautilus_theme_get_image_path ("computer.svg");
-	}
+
+	/* see if the current content view is specifying an icon */
+	icon_name = get_property_from_component (sidebar_title, "icon_name");
 
 	pixbuf = NULL;
-	if (icon_path != NULL) {
-		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_path, NULL, NAUTILUS_ICON_SIZE_LARGE, TRUE);
+	if (icon_name != NULL && strlen (icon_name) > 0) {
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL, NAUTILUS_ICON_SIZE_LARGE, TRUE);
 	} else if (nautilus_icon_factory_is_icon_ready_for_file (sidebar_title->details->file)) {
 		pixbuf = nautilus_icon_factory_get_pixbuf_for_file (sidebar_title->details->file,
 								    "accept",
@@ -446,37 +514,33 @@ update_icon (NautilusSidebarTitle *sidebar_title)
 	}
 	
 	g_free (uri);	
-	g_free (icon_path);
-
+	g_free (icon_name);
+	
 	if (pixbuf != NULL) {
 		sidebar_title->details->determined_icon = TRUE;
 	}
 
 	if (!leave_pixbuf_unchanged) {
-		nautilus_image_set_pixbuf (NAUTILUS_IMAGE (sidebar_title->details->icon), pixbuf);
+		eel_image_set_pixbuf (EEL_IMAGE (sidebar_title->details->icon), pixbuf);
 	}
 }
 
 static void
-update_font (NautilusSidebarTitle *sidebar_title)
+update_title_font (NautilusSidebarTitle *sidebar_title)
 {
-	const int maximum_acceptable_font_size = 20;
-	const int minimum_acceptable_font_size = 12;
-	const int slop_offset = 4;
-
 	int available_width;
 	GdkFont *template_font;
 	GdkFont *bold_template_font;
 	GdkFont *largest_fitting_font;
 	int largest_fitting_smooth_font_size;
-	NautilusScalableFont *smooth_font;
+	EelScalableFont *smooth_font;
 
 	/* Make sure theres work to do */
-	if (nautilus_strlen (sidebar_title->details->title_text) < 1) {
+	if (eel_strlen (sidebar_title->details->title_text) < 1) {
 		return;
 	}
 
-	available_width = GTK_WIDGET (sidebar_title)->allocation.width - slop_offset;
+	available_width = GTK_WIDGET (sidebar_title)->allocation.width - TITLE_PADDING;
 
 	/* No work to do */
 	if (available_width <= 0) {
@@ -484,50 +548,50 @@ update_font (NautilusSidebarTitle *sidebar_title)
 	}
 	
 	/* Update the smooth font */
-	smooth_font = nautilus_label_get_smooth_font (NAUTILUS_LABEL (sidebar_title->details->title_label));
-	largest_fitting_smooth_font_size = nautilus_scalable_font_largest_fitting_font_size (smooth_font,
-											     sidebar_title->details->title_text,
-											     available_width,
-											     minimum_acceptable_font_size,
-											     maximum_acceptable_font_size);
+	smooth_font = eel_label_get_smooth_font (EEL_LABEL (sidebar_title->details->title_label));
+	largest_fitting_smooth_font_size = eel_scalable_font_largest_fitting_font_size
+		(smooth_font,
+		 sidebar_title->details->title_text,
+		 available_width,
+		 MIN_TITLE_FONT_SIZE,
+		 MAX_TITLE_FONT_SIZE);
+	
+	eel_label_set_smooth_font_size (EEL_LABEL (sidebar_title->details->title_label), 
+					largest_fitting_smooth_font_size);
+	
 	gtk_object_unref (GTK_OBJECT (smooth_font));
 
-	nautilus_label_set_smooth_font_size (NAUTILUS_LABEL (sidebar_title->details->title_label), largest_fitting_smooth_font_size);
-
-	/* FIXME bugzilla.eazel.com 1103: Hard coded font family. */
-	
 	/* Update the regular font */
-	template_font = nautilus_font_factory_get_font_by_family (_("helvetica"), maximum_acceptable_font_size);
-	g_assert (template_font != NULL);
-
-	bold_template_font = nautilus_gdk_font_get_bold (template_font);
+	template_font = get_non_smooth_font (MAX_TITLE_FONT_SIZE);
+	bold_template_font = eel_gdk_font_get_bold (template_font);
 	
-	largest_fitting_font = nautilus_gdk_font_get_largest_fitting (template_font,
-								      sidebar_title->details->title_text,
-								      available_width,
-								      minimum_acceptable_font_size,
-								      maximum_acceptable_font_size);
+	largest_fitting_font = eel_gdk_font_get_largest_fitting
+		(bold_template_font,
+		 sidebar_title->details->title_text,
+		 available_width,
+		 MIN_TITLE_FONT_SIZE,
+		 MAX_TITLE_FONT_SIZE);
 	
 	if (largest_fitting_font == NULL) {
-		largest_fitting_font = nautilus_gdk_font_get_fixed ();
+		largest_fitting_font = eel_gdk_font_get_fixed ();
 	}
 	
-	nautilus_gtk_widget_set_font (sidebar_title->details->title_label, largest_fitting_font);
+	eel_gtk_widget_set_font (sidebar_title->details->title_label,
+				      largest_fitting_font);
 	
 	gdk_font_unref (largest_fitting_font);
 	gdk_font_unref (bold_template_font);
 	gdk_font_unref (template_font);
 }
 
-/* set up the filename label */
 static void
 update_title (NautilusSidebarTitle *sidebar_title)
 {
-	/* FIXME bugzilla.eazel.com 2500: We could defer showing the title until the icon is ready. */
-	nautilus_label_set_text (NAUTILUS_LABEL (sidebar_title->details->title_label),
-				  sidebar_title->details->title_text);
-
-	update_font (sidebar_title);
+	/* FIXME bugzilla.gnome.org 42500: We could defer showing the title until the icon is ready. */
+	if (eel_label_set_text (EEL_LABEL (sidebar_title->details->title_label),
+				     sidebar_title->details->title_text)) {
+		update_title_font (sidebar_title);
+	}
 }
 
 static void
@@ -556,45 +620,72 @@ file_is_search_location (NautilusFile *file)
 	return is_search_uri;
 }
 
+static int
+measure_width_callback (const char *string, void *context)
+{
+	EelLabel *label;
+	EelScalableFont *smooth_font;
+	int smooth_font_size;
+	
+	label = (EelLabel*) context;
+	smooth_font = eel_label_get_smooth_font (label); 
+	smooth_font_size = eel_label_get_smooth_font_size (label);
+	return eel_scalable_font_text_width (smooth_font, smooth_font_size, string, strlen (string));
+}
+
 static void
 update_more_info (NautilusSidebarTitle *sidebar_title)
 {
 	NautilusFile *file;
 	GString *info_string;
-	char *type_string, *search_string, *search_uri;
+	char *type_string, *component_info;
+	char *search_string, *search_uri;
+	char *date_modified_str;
+	int sidebar_width;
 	
 	file = sidebar_title->details->file;
-	
-	/* FIXME bugzilla.eazel.com 2500: We could defer showing info until the icon is ready. */
-	/* Adding this special case for search results to 
-	   correspond to the fix for bug 2341.  */
-	if (file != NULL && file_is_search_location (file)) {
-		search_uri = nautilus_file_get_uri (file);
-		search_string = nautilus_search_uri_to_human (search_uri);
-		g_free (search_uri);
-		info_string = g_string_new (search_string);
-		g_free (search_string);
-		append_and_eat (info_string, "\n ",
-				nautilus_file_get_string_attribute (file, "size"));
-	}
-	else {
-		info_string = g_string_new (NULL);
-		type_string = nautilus_file_get_string_attribute (file, "type");
-		if (type_string != NULL) {
-			append_and_eat (info_string, NULL, type_string);
-			append_and_eat (info_string, ", ",
+
+	/* allow components to specify the info if they wish to */
+	component_info = get_property_from_component (sidebar_title, "summary_info");
+	if (component_info != NULL && strlen (component_info) > 0) {
+		info_string = g_string_new (component_info);
+		g_free (component_info);
+	} else {
+		/* FIXME bugzilla.gnome.org 42500: We could defer showing info until the icon is ready. */
+		/* Adding this special case for search results to 
+		   correspond to the fix for bug 2341.  */
+		if (file != NULL && file_is_search_location (file)) {
+			search_uri = nautilus_file_get_uri (file);
+			search_string = nautilus_search_uri_to_human (search_uri);
+			g_free (search_uri);
+			info_string = g_string_new (search_string);
+			g_free (search_string);
+			append_and_eat (info_string, "\n ",
 					nautilus_file_get_string_attribute (file, "size"));
 		} else {
-			append_and_eat (info_string, NULL,
-					nautilus_file_get_string_attribute (file, "size"));
+			info_string = g_string_new (NULL);
+			type_string = nautilus_file_get_string_attribute (file, "type");
+			if (type_string != NULL) {
+				append_and_eat (info_string, NULL, type_string);
+				append_and_eat (info_string, ", ",
+						nautilus_file_get_string_attribute (file, "size"));
+			} else {
+				append_and_eat (info_string, NULL,
+						nautilus_file_get_string_attribute (file, "size"));
+			}
+			
+			sidebar_width = GTK_WIDGET (sidebar_title)->allocation.width - 2 * SIDEBAR_INFO_MARGIN;
+			if (sidebar_width > MINIMUM_INFO_WIDTH) {
+				date_modified_str = nautilus_file_fit_modified_date_as_string (file, sidebar_width,
+											measure_width_callback, NULL,
+											sidebar_title->details->more_info_label);
+				append_and_eat (info_string, "\n", date_modified_str);
+				g_string_append_c (info_string, '\0');
+			}
 		}
-		append_and_eat (info_string, "\n",
-				nautilus_file_get_string_attribute (file, "date_modified"));
-		g_string_append_c (info_string, '\0');
 	}
-
-	nautilus_label_set_text (NAUTILUS_LABEL (sidebar_title->details->more_info_label),
-				  info_string->str);
+	eel_label_set_text (EEL_LABEL (sidebar_title->details->more_info_label),
+			    info_string->str);
 
 	g_string_free (info_string, TRUE);
 }
@@ -605,8 +696,8 @@ add_emblem (NautilusSidebarTitle *sidebar_title, GdkPixbuf *pixbuf)
 {
 	GtkWidget *image_widget;
 
-	image_widget = nautilus_image_new_with_background (NULL);
-	nautilus_image_set_pixbuf (NAUTILUS_IMAGE (image_widget), pixbuf);	
+	image_widget = eel_image_new_with_background (NULL);
+	eel_image_set_pixbuf (EEL_IMAGE (image_widget), pixbuf);	
   	gtk_widget_show (image_widget);
 	gtk_container_add (GTK_CONTAINER (sidebar_title->details->emblem_box), image_widget);	
 }
@@ -617,7 +708,7 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 	GList *icons, *p;
 	GdkPixbuf *pixbuf;
 
-	/* FIXME bugzilla.eazel.com 2500: We could defer showing emblems until the icon is ready. */
+	/* FIXME bugzilla.gnome.org 42500: We could defer showing emblems until the icon is ready. */
 	/* exit if we don't have the file yet */
 	if (sidebar_title->details->file == NULL) {
 		return;
@@ -628,12 +719,8 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 			       (GtkCallback) gtk_widget_destroy,
 			       NULL);
 
-	/* make sure we have the file */
-	if (sidebar_title->details->file) {
-	}
-	
 	/* fetch the emblem icons from metadata */
-	icons = nautilus_icon_factory_get_emblem_icons_for_file (sidebar_title->details->file, FALSE, NULL);
+	icons = nautilus_icon_factory_get_emblem_icons_for_file (sidebar_title->details->file, NULL);
 
 	/* loop through the list of emblems, installing them in the box */
 	for (p = icons; p != NULL; p = p->next) {
@@ -641,7 +728,7 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 			(p->data,
 			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
 			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
-			 NULL, FALSE);
+			 FALSE, NULL, FALSE);
 		if (pixbuf != NULL) {
 			add_emblem (sidebar_title, pixbuf);
 			gdk_pixbuf_unref (pixbuf);
@@ -656,7 +743,7 @@ update_notes (NautilusSidebarTitle *sidebar_title)
 {
 	char *text;
 	
-	/* FIXME bugzilla.eazel.com 2500: We could defer showing notes until the icon is ready. */
+	/* FIXME bugzilla.gnome.org 42500: We could defer showing notes until the icon is ready. */
 
 	text = nautilus_file_get_metadata (sidebar_title->details->file,
 					   NAUTILUS_METADATA_KEY_NOTES,
@@ -689,6 +776,44 @@ nautilus_sidebar_title_set_text (NautilusSidebarTitle *sidebar_title,
 	update_title (sidebar_title);
 }
 
+static gboolean
+item_count_ready (NautilusSidebarTitle *sidebar_title)
+{
+	return sidebar_title->details->file != NULL
+		&& nautilus_file_get_directory_item_count
+		(sidebar_title->details->file, NULL, NULL) != 0;
+}
+
+static void
+monitor_add (NautilusSidebarTitle *sidebar_title)
+{
+	GList *attributes;
+
+	/* Monitor the things needed to get the right icon. Don't
+	 * monitor a directory's item count at first even though the
+	 * "size" attribute is based on that, because the main view
+	 * will get it for us in most cases, and in other cases it's
+	 * OK to not show the size -- if we did monitor it, we'd be in
+	 * a race with the main view and could cause it to have to
+	 * load twice. Once we have a size, though, we want to monitor
+	 * the size to guarantee it stays up to date.
+	 */
+
+	sidebar_title->details->monitoring_count = item_count_ready (sidebar_title);
+
+	attributes = nautilus_icon_factory_get_required_file_attributes ();		
+	attributes = g_list_prepend (attributes,
+				     NAUTILUS_FILE_ATTRIBUTE_METADATA);
+	if (sidebar_title->details->monitoring_count) {
+		attributes = g_list_prepend (attributes,
+					     NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_COUNT);
+	}
+
+	nautilus_file_monitor_add (sidebar_title->details->file, sidebar_title, attributes);
+
+	g_list_free (attributes);
+}
+
 static void
 update_all (NautilusSidebarTitle *sidebar_title)
 {
@@ -700,6 +825,12 @@ update_all (NautilusSidebarTitle *sidebar_title)
 	
 	update_emblems (sidebar_title);
 	update_notes (sidebar_title);
+
+	/* Redo monitor once the count is ready. */
+	if (!sidebar_title->details->monitoring_count && item_count_ready (sidebar_title)) {
+		nautilus_file_monitor_remove (sidebar_title->details->file, sidebar_title);
+		monitor_add (sidebar_title);
+	}
 }
 
 void
@@ -707,8 +838,6 @@ nautilus_sidebar_title_set_file (NautilusSidebarTitle *sidebar_title,
 				 NautilusFile *file,
 				 const char *initial_text)
 {
-	GList *attributes;
-
 	if (file != sidebar_title->details->file) {
 		release_file (sidebar_title);
 		sidebar_title->details->file = file;
@@ -718,24 +847,11 @@ nautilus_sidebar_title_set_file (NautilusSidebarTitle *sidebar_title,
 		/* attach file */
 		if (file != NULL) {
 			sidebar_title->details->file_changed_connection =
-				gtk_signal_connect_object (GTK_OBJECT (sidebar_title->details->file),
+				gtk_signal_connect_object (GTK_OBJECT (file),
 							   "changed",
 							   update_all,
 							   GTK_OBJECT (sidebar_title));
-			
-			/* Monitor the things needed to get the right
-			 * icon. Also monitor a directory's item count because
-			 * the "size" attribute is based on that.
-			 */
-			attributes = nautilus_icon_factory_get_required_file_attributes ();		
-			attributes = g_list_prepend (attributes,
-						     NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_COUNT);
-			attributes = g_list_prepend (attributes,
-						     NAUTILUS_FILE_ATTRIBUTE_METADATA);
-
-			nautilus_file_monitor_add (sidebar_title->details->file, sidebar_title,
-						   attributes);
-			g_list_free (attributes);
+			monitor_add (sidebar_title);
 		}
 	}
 
@@ -753,11 +869,12 @@ nautilus_sidebar_title_size_allocate (GtkWidget *widget,
 
 	old_width = widget->allocation.width;
 
-	NAUTILUS_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
 
 	if (old_width != widget->allocation.width) {
-		/* Need to update the font if the width changes. */
-		update_font (NAUTILUS_SIDEBAR_TITLE (widget));
+		/* update the title font and info format as the size changes. */
+		update_title_font (NAUTILUS_SIDEBAR_TITLE (widget));
+		update_more_info (NAUTILUS_SIDEBAR_TITLE (widget));	
 	}
 }
 
@@ -766,7 +883,7 @@ nautilus_sidebar_title_hit_test_icon (NautilusSidebarTitle *sidebar_title, int x
 {
 	g_return_val_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (sidebar_title), FALSE);
 
-	return nautilus_point_in_widget (sidebar_title->details->icon, x, y);
+	return eel_point_in_widget (sidebar_title->details->icon, x, y);
 }
 
 static GtkWidget *
@@ -774,10 +891,10 @@ sidebar_title_create_title_label (void)
 { 
 	GtkWidget *title_label;
 
-	title_label = nautilus_label_new_with_background ("");
-	nautilus_label_make_bold (NAUTILUS_LABEL (title_label));
-	nautilus_label_set_wrap (NAUTILUS_LABEL (title_label), TRUE);
-	nautilus_label_set_justify (NAUTILUS_LABEL (title_label), GTK_JUSTIFY_CENTER);
+	title_label = eel_label_new_with_background ("");
+	eel_label_make_bold (EEL_LABEL (title_label));
+	eel_label_set_wrap (EEL_LABEL (title_label), TRUE);
+	eel_label_set_justify (EEL_LABEL (title_label), GTK_JUSTIFY_CENTER);
 
 	return title_label;
 }
@@ -787,17 +904,10 @@ sidebar_title_create_more_info_label (void)
 {
 	GtkWidget *more_info_label;
 
-	more_info_label = nautilus_label_new_with_background ("");
-	nautilus_label_make_smaller (NAUTILUS_LABEL (more_info_label), 2);
-	nautilus_label_set_justify (NAUTILUS_LABEL (more_info_label), GTK_JUSTIFY_CENTER);
+	more_info_label = eel_label_new_with_background ("");
+	eel_label_make_smaller (EEL_LABEL (more_info_label), 2);
+	eel_label_set_justify (EEL_LABEL (more_info_label), GTK_JUSTIFY_CENTER);
+	eel_label_set_justify (EEL_LABEL (more_info_label), GTK_JUSTIFY_CENTER);
 	
 	return more_info_label;
 }
-
-static void
-update_all_cover (gpointer callback_data)
-{
-	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (callback_data));
-	
-	update_all (NAUTILUS_SIDEBAR_TITLE (callback_data));
-}
